#!/usr/bin/env python


from __future__ import print_function

"""
Simple script to translate a list of waypoints into GPX

Input is CSV::

	waypoint,lat,long[,description]

"""
"""
RCSid:
	$Id: wpt2gpx.py,v 1.4 2022/05/05 18:46:20 sjg Exp $

	@(#) Copyright (c) 2019, Simon J. Gerraty

	This file is provided in the hope that it will
	be of use.  There is absolutely NO WARRANTY.
	Permission to copy, redistribute or otherwise
	use this file is hereby granted provided that 
	the above copyright notice and this notice are
	left intact. 
      
	Please send copies of changes and bug-fixes to:
	sjg@crufty.net

"""

import os
import os.path
import sys
import latlong


fmt_gpx="""<?xml version="1.0"?>
<gpx version="1.1" creator="{}" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="http://www.topografix.com/GPX/1/1" xmlns:gpxx="http://www.garmin.com/xmlschemas/GpxExtensions/v3" xsi:schemaLocation="http://www.topografix.com/GPX/1/1 http://www.topografix.com/GPX/1/1/gpx.xsd" xmlns:opencpn="http://www.opencpn.org">"""

fmt_rte="""<rte>
<name>{}</name>"""

fmt_rtept="""<rtept lat="{}" lon="{}">
<name>{}</name>
<desc>{}</desc>
<sym>diamond</sym>
<type>WPT</type>
</rtept>"""

if __name__ == '__main__':
    import getopt

    opts,args = getopt.getopt(sys.argv[1:], 'dN:f:t:')

    debug = 0
    sep = ','
    myname = 'wpt2gpx'
    for o,a in opts:
        if o == '-d':
            debug += 1
        elif o == '-N':
            myname = a
	elif o == '-t':
	    sep = a

    print(fmt_gpx.format(myname))
    
    for a in args:
        rte = os.path.basename(a)
        print(fmt_rte.format(rte))
        for line in open(a).readlines():
            w = line.strip().split(sep)
            if len(w) < 3 or len(w[2]) == 0:
                continue
	    if debug:
		print('processing {} {} {}'.format(w[0],w[1],w[2]))
	    desc = '\n'.join(w[3:])
            position = latlong.LatLong(w[1],w[2])
            print(fmt_rtept.format(position.latitude, position.longitude, w[0], desc))
        print('</rte>')
    print('</gpx>')

